@@ -182,38 +182,37 @@ struct _ThunarApplicationClass
 
 struct _ThunarApplication
 {
-  GtkApplication                 __parent__;
+  GtkApplication         __parent__;
 
-  ThunarSessionClient            *session_client;
+  ThunarSessionClient   *session_client;
 
-  ThunarPreferences              *preferences;
-  GtkWidget                      *progress_dialog;
+  ThunarPreferences     *preferences;
+  GtkWidget             *progress_dialog;
 
-  ThunarThumbnailCache           *thumbnail_cache;
-  ThunarThumbnailer              *thumbnailer;
+  ThunarThumbnailCache  *thumbnail_cache;
+  ThunarThumbnailer     *thumbnailer;
 
-  ThunarDBusService              *dbus_service;
+  ThunarDBusService     *dbus_service;
 
-  gboolean                        daemon;
+  gboolean               daemon;
 
-  guint                           accel_map_save_id;
-  GtkAccelMap                    *accel_map;
+  guint                  accel_map_save_id;
+  GtkAccelMap           *accel_map;
 
-  guint                           show_dialogs_timer_id;
+  guint                  show_dialogs_timer_id;
 
 #ifdef HAVE_GUDEV
-  GUdevClient                    *udev_client;
+  GUdevClient           *udev_client;
 
-  GSList                         *volman_udis;
-  guint                           volman_idle_id;
-  guint                           volman_watch_id;
+  GSList                *volman_udis;
+  guint                  volman_idle_id;
+  guint                  volman_watch_id;
 #endif
 
-  GList                          *files_to_launch;
-  ThunarApplicationProcessAction  process_file_action;
+  GList                 *files_to_launch;
 
-  guint                           dbus_owner_id_xfce;
-  guint                           dbus_owner_id_fdo;
+  guint                  dbus_owner_id_xfce;
+  guint                  dbus_owner_id_fdo;
 };
 
 
@@ -280,7 +279,6 @@ thunar_application_init (ThunarApplication *application)
    * in the primary instance anyways */
 
   application->files_to_launch = NULL;
-  application->process_file_action = THUNAR_APPLICATION_SELECT_FILES;
   application->progress_dialog = NULL;
   application->preferences     = NULL;
 
@@ -400,7 +398,7 @@ thunar_application_shutdown (GApplication *gapp)
   ThunarApplication *application = THUNAR_APPLICATION (gapp);
 
   /* unqueue all files waiting to be processed */
-  thunar_g_file_list_free (application->files_to_launch);
+  thunar_g_list_free_full (application->files_to_launch);
 
   /* save the current accel map */
   if (G_UNLIKELY (application->accel_map_save_id != 0))
@@ -533,7 +531,7 @@ thunar_application_command_line (GApplication            *gapp,
     }
   else if (filenames != NULL)
     {
-      if (!thunar_application_process_filenames (application, cwd, filenames, NULL, NULL, &error, THUNAR_APPLICATION_SELECT_FILES))
+      if (!thunar_application_process_filenames (application, cwd, filenames, NULL, NULL, &error))
         {
           /* we failed to process the filenames or the bulk rename failed */
           g_application_command_line_printerr (command_line, "Thunar: %s\n", error->message);
@@ -541,7 +539,7 @@ thunar_application_command_line (GApplication            *gapp,
     }
   else if (!daemon)
     {
-      if (!thunar_application_process_filenames (application, cwd, cwd_list, NULL, NULL, &error, THUNAR_APPLICATION_SELECT_FILES))
+      if (!thunar_application_process_filenames (application, cwd, cwd_list, NULL, NULL, &error))
         {
           /* we failed to process the filenames or the bulk rename failed */
           g_application_command_line_printerr (command_line, "Thunar: %s\n", error->message);
@@ -741,7 +739,7 @@ thunar_application_collect_and_launch (ThunarApplication *application,
           g_free (base_name);
 
           /* add to the target file list */
-          target_file_list = thunar_g_file_list_prepend (target_file_list, file);
+          target_file_list = thunar_g_list_prepend_deep (target_file_list, file);
           g_object_unref (file);
         }
     }
@@ -763,7 +761,7 @@ thunar_application_collect_and_launch (ThunarApplication *application,
     }
 
   /* release the target path list */
-  thunar_g_file_list_free (target_file_list);
+  thunar_g_list_free_full (target_file_list);
 }
 
 
@@ -1318,7 +1316,7 @@ thunar_application_open_window (ThunarApplication *application,
           list = g_list_last (list);
 
           if (directory != NULL)
-              thunar_window_notebook_open_new_tab (THUNAR_WINDOW (list->data), directory);
+              thunar_window_notebook_add_new_tab (THUNAR_WINDOW (list->data), directory, TRUE);
           
           /* bring the window to front */
           gtk_window_present (list->data);
@@ -1447,7 +1445,7 @@ thunar_application_bulk_rename (ThunarApplication *application,
 
   /* cleanup */
   g_object_unref (G_OBJECT (current_directory));
-  thunar_g_file_list_free (file_list);
+  thunar_g_list_free_full (file_list);
 
   return result;
 }
@@ -1509,17 +1507,12 @@ thunar_application_process_files_finish (ThunarBrowser *browser,
         }
 
       /* stop processing files */
-      thunar_g_file_list_free (application->files_to_launch);
+      thunar_g_list_free_full (application->files_to_launch);
       application->files_to_launch = NULL;
     }
   else
     {
-      if (application->process_file_action == THUNAR_APPLICATION_LAUNCH_FILES)
-        {
-          /* try to launch the file / open the directory */
-          thunar_file_launch (target_file, screen, startup_id, &error);
-        }
-      else if (thunar_file_is_directory (file))
+      if (thunar_file_is_directory (file))
         {
           thunar_application_open_window (application, file, screen, startup_id, FALSE);
         }
@@ -1610,20 +1603,18 @@ thunar_application_process_files (ThunarApplication *application)
  * @startup_id        : startup id to finish startup notification and properly focus the
  *                      window when focus stealing is enabled or %NULL.
  * @error             : return location for errors or %NULL.
- * @action            : action to invoke on the files
  *
  * Tells @application to process the given @filenames and launch them appropriately.
  *
  * Return value: %TRUE on success, %FALSE if @error is set.
  **/
 gboolean
-thunar_application_process_filenames (ThunarApplication               *application,
-                                      const gchar                     *working_directory,
-                                      gchar                          **filenames,
-                                      GdkScreen                       *screen,
-                                      const gchar                     *startup_id,
-                                      GError                         **error,
-                                      ThunarApplicationProcessAction   action)
+thunar_application_process_filenames (ThunarApplication *application,
+                                      const gchar       *working_directory,
+                                      gchar            **filenames,
+                                      GdkScreen         *screen,
+                                      const gchar       *startup_id,
+                                      GError           **error)
 {
   ThunarFile *file;
   GError     *derror = NULL;
@@ -1671,7 +1662,7 @@ thunar_application_process_filenames (ThunarApplication               *applicati
                        _("Failed to open \"%s\": %s"), filenames[n], derror->message);
           g_error_free (derror);
 
-          thunar_g_file_list_free (file_list);
+          thunar_g_list_free_full (file_list);
 
           return FALSE;
         }
@@ -1695,10 +1686,7 @@ thunar_application_process_filenames (ThunarApplication               *applicati
 
   /* start processing files if we have any to launch */
   if (application->files_to_launch != NULL)
-    {
-      application->process_file_action = action;
-      thunar_application_process_files (application);
-    }
+    thunar_application_process_files (application);
 
   /* free the file list */
   g_list_free (file_list);
@@ -2084,7 +2072,7 @@ thunar_application_move_into (ThunarApplication *application,
   _thunar_return_if_fail (target_file != NULL);
 
   /* launch the appropriate operation depending on the target file */
-  if (thunar_g_file_is_trashed (target_file))
+  if (thunar_g_file_is_trash (target_file))
     {
       thunar_application_trash (application, parent, source_file_list);
     }
@@ -2154,7 +2142,7 @@ thunar_application_unlink_files (ThunarApplication *application,
   for (lp = g_list_last (file_list); lp != NULL; lp = lp->prev, ++n_path_list)
     {
       /* prepend the path to the path list */
-      path_list = thunar_g_file_list_prepend (path_list, thunar_file_get_file (lp->data));
+      path_list = thunar_g_list_prepend_deep (path_list, thunar_file_get_file (lp->data));
 
       /* permanently delete if at least one of the file is not a local
        * file (e.g. resides in the trash) or cannot be trashed */
@@ -2221,7 +2209,7 @@ thunar_application_unlink_files (ThunarApplication *application,
     }
 
   /* release the path list */
-  thunar_g_file_list_free (path_list);
+  thunar_g_list_free_full (path_list);
 }
 
 
@@ -2450,8 +2438,8 @@ thunar_application_restore_files (ThunarApplication *application,
       /* TODO we might have to distinguish between URIs and paths here */
       target_path = g_file_new_for_commandline_arg (original_uri);
 
-      source_path_list = thunar_g_file_list_append (source_path_list, thunar_file_get_file (lp->data));
-      target_path_list = thunar_g_file_list_append (target_path_list, target_path);
+      source_path_list = thunar_g_list_append_deep (source_path_list, thunar_file_get_file (lp->data));
+      target_path_list = thunar_g_list_append_deep (target_path_list, target_path);
 
       g_object_unref (target_path);
     }
@@ -2472,8 +2460,8 @@ thunar_application_restore_files (ThunarApplication *application,
     }
 
   /* free path lists */
-  thunar_g_file_list_free (source_path_list);
-  thunar_g_file_list_free (target_path_list);
+  thunar_g_list_free_full (source_path_list);
+  thunar_g_list_free_full (target_path_list);
 }
 
 
