@@ -93,10 +93,10 @@ thunar_component_class_init (gpointer klass)
  * thunar_component_get_selected_files:
  * @component : a #ThunarComponent instance.
  *
- * Returns the set of selected files. Check the description
+ * Returns the set of selected #ThunarFile<!---->s. Check the description
  * of the :selected-files property for details.
  *
- * Return value: the set of selected files.
+ * Return value: the set of selected #ThunarFile<!---->s.
  **/
 GList*
 thunar_component_get_selected_files (ThunarComponent *component)
@@ -140,7 +140,7 @@ thunar_component_restore_selection (ThunarComponent *component)
 
   _thunar_return_if_fail (THUNAR_IS_COMPONENT (component));
 
-  selected_files = thunar_g_file_list_copy (thunar_component_get_selected_files (component));
+  selected_files = thunar_g_list_copy_deep (thunar_component_get_selected_files (component));
   thunar_component_set_selected_files (component, selected_files);
-  thunar_g_file_list_free (selected_files);
+  thunar_g_list_free_full (selected_files);
 }
