@@ -47,6 +47,7 @@ typedef struct _ThunarFile      ThunarFile;
  * @THUNAR_FILE_DATE_CHANGED  : date of last change to the file meta data or the content.
  * @THUNAR_FILE_DATE_CREATED  : date of file creation.
  * @THUNAR_FILE_DATE_MODIFIED : date of last modification of the file's content.
+ * @THUNAR_FILE_DATE_DELETED  : date of file deletion.
  *
  * The various dates that can be queried about a #ThunarFile. Note, that not all
  * #ThunarFile implementations support all types listed above. See the documentation
@@ -58,6 +59,7 @@ typedef enum
   THUNAR_FILE_DATE_CHANGED,
   THUNAR_FILE_DATE_CREATED,
   THUNAR_FILE_DATE_MODIFIED,
+  THUNAR_FILE_DATE_DELETED,
 } ThunarFileDateType;
 
 /**
@@ -209,6 +211,7 @@ gboolean          thunar_file_is_writable                (const ThunarFile
 gboolean          thunar_file_is_hidden                  (const ThunarFile       *file);
 gboolean          thunar_file_is_home                    (const ThunarFile       *file);
 gboolean          thunar_file_is_regular                 (const ThunarFile       *file) G_GNUC_PURE;
+gboolean          thunar_file_is_trash                   (const ThunarFile       *file);
 gboolean          thunar_file_is_trashed                 (const ThunarFile       *file);
 gboolean          thunar_file_is_desktop_file            (const ThunarFile       *file,
                                                           gboolean               *is_secure);
@@ -243,6 +246,7 @@ GFilesystemPreviewType thunar_file_get_preview_type      (const ThunarFile *file
 const gchar      *thunar_file_get_icon_name              (ThunarFile              *file,
                                                           ThunarFileIconState      icon_state,
                                                           GtkIconTheme            *icon_theme);
+const gchar      *thunar_file_get_device_type            (ThunarFile              *file);
 
 void              thunar_file_watch                      (ThunarFile              *file);
 void              thunar_file_unwatch                    (ThunarFile              *file);
