@@ -65,7 +65,7 @@ _tij_collect_nofollow (ThunarJob *job,
                                                   TRUE, unlinking, FALSE, &err);
 
       /* prepend the new files to the existing list */
-      file_list = thunar_g_file_list_prepend (file_list, lp->data);
+      file_list = thunar_g_list_prepend_deep (file_list, lp->data);
       file_list = g_list_concat (child_file_list, file_list);
     }
 
@@ -78,7 +78,7 @@ _tij_collect_nofollow (ThunarJob *job,
         g_propagate_error (error, err);
 
       /* release the collected files */
-      thunar_g_file_list_free (file_list);
+      thunar_g_list_free_full (file_list);
 
       return NULL;
     }
@@ -469,7 +469,7 @@ _thunar_io_jobs_unlink (ThunarJob  *job,
       else
         g_propagate_error (error, err);
 
-      thunar_g_file_list_free (file_list);
+      thunar_g_list_free_full (file_list);
       return FALSE;
     }
 
@@ -551,7 +551,7 @@ again:
   g_object_unref (thumbnail_cache);
 
   /* release the file list */
-  thunar_g_file_list_free (file_list);
+  thunar_g_list_free_full (file_list);
 
   if (exo_job_set_error_if_cancelled (EXO_JOB (job), error))
     return FALSE;
@@ -784,7 +784,7 @@ _thunar_io_jobs_link (ThunarJob  *job,
           /* queue the file for the folder update unless it was skipped */
           if (sp->data != real_target_file)
             {
-              new_files_list = thunar_g_file_list_prepend (new_files_list,
+              new_files_list = thunar_g_list_prepend_deep (new_files_list,
                                                            real_target_file);
 
               /* notify the thumbnail cache that we need to copy the original
@@ -804,14 +804,14 @@ _thunar_io_jobs_link (ThunarJob  *job,
 
   if (err != NULL)
     {
-      thunar_g_file_list_free (new_files_list);
+      thunar_g_list_free_full (new_files_list);
       g_propagate_error (error, err);
       return FALSE;
     }
   else
     {
       thunar_job_new_files (THUNAR_JOB (job), new_files_list);
-      thunar_g_file_list_free (new_files_list);
+      thunar_g_list_free_full (new_files_list);
       return TRUE;
     }
 }
@@ -961,7 +961,7 @@ _thunar_io_jobs_chown (ThunarJob  *job,
   if (recursive)
     file_list = _tij_collect_nofollow (job, file_list, FALSE, &err);
   else
-    file_list = thunar_g_file_list_copy (file_list);
+    file_list = thunar_g_list_copy_deep (file_list);
 
   if (err != NULL)
     {
@@ -1033,7 +1033,7 @@ retry_chown:
     }
 
   /* release the file list */
-  thunar_g_file_list_free (file_list);
+  thunar_g_list_free_full (file_list);
 
   if (err != NULL)
     {
@@ -1104,7 +1104,7 @@ _thunar_io_jobs_chmod (ThunarJob  *job,
   if (recursive)
     file_list = _tij_collect_nofollow (job, file_list, FALSE, &err);
   else
-    file_list = thunar_g_file_list_copy (file_list);
+    file_list = thunar_g_list_copy_deep (file_list);
 
   if (err != NULL)
     {
@@ -1185,7 +1185,7 @@ retry_chown:
     }
 
   /* release the file list */
-  thunar_g_file_list_free (file_list);
+  thunar_g_list_free_full (file_list);
 
   if (err != NULL)
     {
@@ -1273,7 +1273,7 @@ _thunar_io_jobs_ls (ThunarJob  *job,
         {
           /* none of the handlers took over the file list, so it's up to us
            * to destroy it */
-          thunar_g_file_list_free (file_list);
+          thunar_g_list_free_full (file_list);
         }
     }
 
