@@ -161,6 +161,9 @@ static gint               sort_by_date_accessed                   (const ThunarF
 static gint               sort_by_date_modified                   (const ThunarFile       *a,
                                                                    const ThunarFile       *b,
                                                                    gboolean                case_sensitive);
+static gint               sort_by_date_deleted                    (const ThunarFile       *a,
+                                                                   const ThunarFile       *b,
+                                                                   gboolean                case_sensitive);
 static gint               sort_by_group                           (const ThunarFile       *a,
                                                                    const ThunarFile       *b,
                                                                    gboolean                case_sensitive);
@@ -610,6 +613,9 @@ thunar_list_model_get_column_type (GtkTreeModel *model,
     case THUNAR_COLUMN_DATE_MODIFIED:
       return G_TYPE_STRING;
 
+    case THUNAR_COLUMN_DATE_DELETED:
+      return G_TYPE_STRING;
+
     case THUNAR_COLUMN_GROUP:
       return G_TYPE_STRING;
 
@@ -700,10 +706,12 @@ thunar_list_model_get_value (GtkTreeModel *model,
 {
   ThunarGroup *group;
   const gchar *content_type;
+  const gchar *device_type;
   const gchar *name;
   const gchar *real_name;
   ThunarUser  *user;
   ThunarFile  *file;
+  GFile       *g_file;
   gchar       *str;
 
   _thunar_return_if_fail (THUNAR_IS_LIST_MODEL (model));
@@ -732,6 +740,12 @@ thunar_list_model_get_value (GtkTreeModel *model,
       g_value_take_string (value, str);
       break;
 
+    case THUNAR_COLUMN_DATE_DELETED:
+      g_value_init (value, G_TYPE_STRING);
+      str = thunar_file_get_date_string (file, THUNAR_FILE_DATE_DELETED, THUNAR_LIST_MODEL (model)->date_style, THUNAR_LIST_MODEL (model)->date_custom_style);
+      g_value_take_string (value, str);
+      break;
+
     case THUNAR_COLUMN_GROUP:
       g_value_init (value, G_TYPE_STRING);
       group = thunar_file_get_group (file);
@@ -789,7 +803,17 @@ thunar_list_model_get_value (GtkTreeModel *model,
 
     case THUNAR_COLUMN_SIZE:
       g_value_init (value, G_TYPE_STRING);
-      g_value_take_string (value, thunar_file_get_size_string_formatted (file, THUNAR_LIST_MODEL (model)->file_size_binary));
+      if (thunar_file_is_mountable (file))
+        {
+          g_file = thunar_file_get_target_location (file);
+          if (g_file == NULL)
+            break;
+          g_value_take_string (value, thunar_g_file_get_free_space_string (g_file, THUNAR_LIST_MODEL (model)->file_size_binary));
+          g_object_unref (g_file);
+          break;
+        }
+      if (!thunar_file_is_directory (file))
+        g_value_take_string (value, thunar_file_get_size_string_formatted (file, THUNAR_LIST_MODEL (model)->file_size_binary));
       break;
 
     case THUNAR_COLUMN_SIZE_IN_BYTES:
@@ -800,12 +824,21 @@ thunar_list_model_get_value (GtkTreeModel *model,
     case THUNAR_COLUMN_TYPE:
       g_value_init (value, G_TYPE_STRING);
       if (G_UNLIKELY (thunar_file_is_symlink (file)))
-        g_value_take_string (value, g_strdup_printf (_("link to %s"), thunar_file_get_symlink_target (file)));
-      else
         {
-          content_type = thunar_file_get_content_type (file);
-          if (content_type != NULL)
-            g_value_take_string (value, g_content_type_get_description (content_type));
+          g_value_take_string (value, g_strdup_printf (_("link to %s"), thunar_file_get_symlink_target (file)));
+          break;
+        }
+      device_type = thunar_file_get_device_type (file);
+      if (device_type != NULL)
+        {
+          g_value_take_string (value, g_strdup (device_type));
+          break;
+        }
+      content_type = thunar_file_get_content_type (file);
+      if (content_type != NULL)
+        {
+          g_value_take_string (value, g_content_type_get_description (content_type));
+          break;
         }
       break;
 
@@ -964,6 +997,8 @@ thunar_list_model_get_sort_column_id (GtkTreeSortable *sortable,
     *sort_column_id = THUNAR_COLUMN_DATE_ACCESSED;
   else if (store->sort_func == sort_by_date_modified)
     *sort_column_id = THUNAR_COLUMN_DATE_MODIFIED;
+  else if (store->sort_func == sort_by_date_deleted)
+    *sort_column_id = THUNAR_COLUMN_DATE_DELETED;
   else if (store->sort_func == sort_by_type)
     *sort_column_id = THUNAR_COLUMN_TYPE;
   else if (store->sort_func == sort_by_owner)
@@ -1009,6 +1044,10 @@ thunar_list_model_set_sort_column_id (GtkTreeSortable *sortable,
       store->sort_func = sort_by_date_modified;
       break;
 
+    case THUNAR_COLUMN_DATE_DELETED:
+      store->sort_func = sort_by_date_deleted;
+      break;
+
     case THUNAR_COLUMN_GROUP:
       store->sort_func = sort_by_group;
       break;
@@ -1472,6 +1511,27 @@ sort_by_date_modified (const ThunarFile *a,
 
 
 
+static gint
+sort_by_date_deleted (const ThunarFile *a,
+                      const ThunarFile *b,
+                      gboolean          case_sensitive)
+{
+  guint64 date_a;
+  guint64 date_b;
+
+  date_a = thunar_file_get_date (a, THUNAR_FILE_DATE_DELETED);
+  date_b = thunar_file_get_date (b, THUNAR_FILE_DATE_DELETED);
+
+  if (date_a < date_b)
+    return -1;
+  else if (date_a > date_b)
+    return 1;
+
+  return thunar_file_compare_by_name (a, b, case_sensitive);
+}
+
+
+
 static gint
 sort_by_group (const ThunarFile *a,
                const ThunarFile *b,
@@ -2297,8 +2357,9 @@ thunar_list_model_get_paths_for_files (ThunarListModel *store,
 
 /**
  * thunar_list_model_get_paths_for_pattern:
- * @store   : a #ThunarListModel instance.
- * @pattern : the pattern to match.
+ * @store          : a #ThunarListModel instance.
+ * @pattern        : the pattern to match.
+ * @case_sensitive : %TRUE to use case sensitive search.
  *
  * Looks up all rows in the @store that match @pattern and returns
  * a list of #GtkTreePath<!---->s corresponding to the rows.
@@ -2312,20 +2373,32 @@ thunar_list_model_get_paths_for_files (ThunarListModel *store,
  **/
 GList*
 thunar_list_model_get_paths_for_pattern (ThunarListModel *store,
-                                         const gchar     *pattern)
+                                         const gchar     *pattern,
+                                         gboolean         case_sensitive)
 {
   GPatternSpec  *pspec;
+  gchar         *case_folded_pattern;
   GList         *paths = NULL;
   GSequenceIter *row;
   GSequenceIter *end;
   ThunarFile    *file;
+  const gchar   *display_name;
+  gchar         *case_folded_display_name;
+  gboolean       name_matched;
   gint           i = 0;
 
   _thunar_return_val_if_fail (THUNAR_IS_LIST_MODEL (store), NULL);
   _thunar_return_val_if_fail (g_utf8_validate (pattern, -1, NULL), NULL);
 
   /* compile the pattern */
-  pspec = g_pattern_spec_new (pattern);
+  if (case_sensitive)
+    pspec = g_pattern_spec_new (pattern);
+  else
+    {
+      case_folded_pattern = g_utf8_casefold (pattern, strlen (pattern));
+      pspec = g_pattern_spec_new (case_folded_pattern);
+      g_free (case_folded_pattern);
+    }
 
   row = g_sequence_get_begin_iter (store->rows);
   end = g_sequence_get_end_iter (store->rows);
@@ -2334,7 +2407,18 @@ thunar_list_model_get_paths_for_pattern (ThunarListModel *store,
   while (row != end)
     {
       file = g_sequence_get (row);
-      if (g_pattern_match_string (pspec, thunar_file_get_display_name (file)))
+      display_name = thunar_file_get_display_name (file);
+
+      if (case_sensitive)
+        name_matched = g_pattern_match_string (pspec, display_name);
+      else
+        {
+          case_folded_display_name = g_utf8_casefold (display_name, strlen (display_name));
+          name_matched = g_pattern_match_string (pspec, case_folded_display_name);
+          g_free (case_folded_display_name);
+        }
+
+      if (name_matched)
         {
           _thunar_assert (i == g_sequence_iter_get_position (row));
           paths = g_list_prepend (paths, gtk_tree_path_new_from_indices (i, -1));
@@ -2605,7 +2689,7 @@ thunar_list_model_get_statusbar_text (ThunarListModel *store,
           gtk_tree_model_get_iter (GTK_TREE_MODEL (store), &iter, lp->data);
           relevant_files = g_list_append (relevant_files, g_sequence_get (iter.user_data));
         }
-        
+
       size_string = thunar_list_model_get_statusbar_text_for_files (relevant_files, show_file_size_binary_format);
       text = g_strdup_printf (_("Selection: %s"), size_string);
       g_free (size_string);
